==> tine20-allinone_2020.08.8.tar.bz2: Tasks/js/Tasks-lang-nl_NL-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: nl_NL\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "GENDER_Task, GENDER_Tasks"
: [
  ""
 ,""

]
, "Task, Tasks"
: [
  "Taak"
 ,"Taken"

]
, "Percent"
: "Procent"

, "Completed"
: "Afgerond"

, "Due"
: "vervallen"

, "Class"
: ""

, "Description"
: "Omschrijving"

, "Geo"
: ""

, "Location"
: ""

, "Organizer"
: "Organisator"

, "Priority"
: "Prioriteit"

, "Status, Status"
: [
  "Status"
 ,"Statussen"

]
, "Lead"
: "Hoofdtaak"

, "Telephone"
: "Telefoon"

, "Email"
: "Email"

, "Add New Task"
: "Nieuwe  taak toevoegen"

, "You have to supply a due date, because an alarm ist set!"
: "Je moet een vervaldatum opgeven, omdat er een alarm is ingesteld!"

, "Summary"
: "Overzicht"

, "Due date"
: "Vervaldag"

, "Add Responsible ..."
: "Voeg verantwoordelijke ..."

, "Notes"
: "Notities"

, "Enter description..."
: "Voer beschrijving in..."

, "Percentage"
: "Percentage"

, "Tasks"
: "Taken"

, "to do list, to do lists"
: [
  "to do lijst"
 ,"to do lijsten"

]
, "to do lists"
: "to do lijsten"

, "Quick Search"
: "Snel zoeken"

, "Due Date"
: "Vervaldag"

, "Responsible"
: "Verantwoordlijk"

, "Last Modified Time"
: "Laatst gewijzigd"

, "Last Modified By"
: "Laatst gewijzigd door"

, "Creation Time"
: "Aanmaak tijd"

, "Created By"
: "Aangemaakt door"

, "New Task"
: "Nieuwe taak"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Wil je deze taak echt verwijderen?"
 ,"Wil je deze taken echt verwijderen?"

]
, "Attachments"
: ""

, "Tags"
: "Labels"

, "Lead name"
: "Hoofd naam"

, "Add a task..."
: "Voeg een taak toe..."

, "All my tasks"
: "Al mijn taken"

, "Default Favorite"
: "Standaard favoriet"

, "The default favorite which is loaded on Tasks startup"
: "De standaard favoriet die bij het opstarten van Taken wordt geladen"

, "Default Task List"
: "Standaard taken lijst"

, "The default task list to create new tasks in."
: "De standaard taken lijst voor nieuwe taken."

, "Tasks status available"
: "Taak status beschikbaar"

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: "Mogelijke taken beschikbaarheid. Houd er rekening mee dat de extra beschikbaarheid van de deelnemer extra invloed kan hebben op de uitvoer en synchronisatie."

, "No response"
: "Geen reactie"

, "Cancelled"
: "Geannuleerd"

, "In process"
: "In behandeling"

, "Task priorities available"
: "Taak prioriteiten beschikbaar"

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: "Mogelijke taak prioriteiten. Houd er rekening mee dat de extra prioriteiten invloed kunnen hebben op andere systeemtaken op de uitvoer en synchronisatie."

, "low"
: "laag"

, "normal"
: "normaal"

, "high"
: "hoog"

, "urgent"
: "urgent"

, "manage shared task lists"
: "Beheer gedeelde taken lijst"

, "Create new shared tasks lists"
: "Maak nieuwe gedeelde taken lijst"

, "manage shared tasks favorites"
: "Beheer gedeelde taak favorieten"

, "Create or update shared tasks favorites"
: "Maak of update gedeelde taak favorieten"

, "%s's personal tasks"
: "%s's persoonlijke taken"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: "Alle taken van mijn takenlijst"

, "My open tasks"
: "Mijn open taken"

, "My open tasks this week"
: "Mijn open taken deze week"

, "All tasks for me"
: "Alle taken voor mij"

, "All tasks that I am responsible for"
: "Alle taken waar ik verantwoordelijk voor ben"

, "Last modified by me"
: "Laatst aangepast door mij"

, "All tasks that I have last modified"
: "Alle taken die die ik als laatst heb aangepast"

, "Tasks without responsible"
: "Taken zonder verantwoordelijke"

, "GENDER_Task"
: ""

, "Task"
: "Taak"

, "Status"
: "Status"

, "to do list"
: "to do lijst"

, "Do you really want to delete the selected task?"
: "Wil je deze taak echt verwijderen?"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Tasks/js/Tasks-lang-nl_NL-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nLanguage: nl_NL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Add New Task"
: "Nieuwe  taak toevoegen"

, "You have to supply a due date, because an alarm ist set!"
: "Je moet een vervaldatum opgeven, omdat er een alarm is ingesteld!"

, "Summary"
: "Overzicht"

, "Due date"
: "Vervaldag"

, "Priority"
: "Prioriteit"

, "Organizer"
: "Organisator"

, "Add Responsible ..."
: "Voeg verantwoordelijke ..."

, "Notes"
: "Notities"

, "Enter description..."
: "Voer beschrijving in..."

, "Percentage"
: "Percentage"

, "Status, Status"
: [
  "Status"
 ,"Statussen"

]
, "Completed"
: "Afgerond"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Wil je deze taak echt verwijderen?"
 ,"Wil je deze taken echt verwijderen?"

]
, "Attachments"
: ""

, "Tags"
: "Labels"

, "Lead name"
: "Hoofd naam"

, "Add a task..."
: "Voeg een taak toe..."

, "Due Date"
: "Vervaldag"

, "Percent"
: "Procent"

, "Responsible"
: "Verantwoordlijk"

, "Task, Tasks"
: [
  "Taak"
 ,"Taken"

]
, "Tasks"
: "Taken"

, "to do list, to do lists"
: [
  "to do lijst"
 ,"to do lijsten"

]
, "to do lists"
: "to do lijsten"

, "Quick Search"
: "Snel zoeken"

, "Last Modified Time"
: "Laatst gewijzigd"

, "Last Modified By"
: "Laatst gewijzigd door"

, "Creation Time"
: "Aanmaak tijd"

, "Created By"
: "Aangemaakt door"

, "New Task"
: "Nieuwe taak"

, "All my tasks"
: "Al mijn taken"

, "Default Favorite"
: "Standaard favoriet"

, "The default favorite which is loaded on Tasks startup"
: "De standaard favoriet die bij het opstarten van Taken wordt geladen"

, "Default Task List"
: "Standaard taken lijst"

, "The default task list to create new tasks in."
: "De standaard taken lijst voor nieuwe taken."

, "Enable Standard Alarm"
: ""

, "New task get a standard alarm as defined below"
: ""

, "Standard Alarm Time"
: ""

, "Minutes before the task ends"
: ""

, "Tasks status available"
: "Taak status beschikbaar"

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: "Mogelijke taken beschikbaarheid. Houd er rekening mee dat de extra beschikbaarheid van de deelnemer extra invloed kan hebben op de uitvoer en synchronisatie."

, "No response"
: "Geen reactie"

, "Cancelled"
: "Geannuleerd"

, "In process"
: "In behandeling"

, "Task priorities available"
: "Taak prioriteiten beschikbaar"

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: "Mogelijke taak prioriteiten. Houd er rekening mee dat de extra prioriteiten invloed kunnen hebben op andere systeemtaken op de uitvoer en synchronisatie."

, "low"
: "laag"

, "normal"
: "normaal"

, "high"
: "hoog"

, "urgent"
: "urgent"

, "%s's personal tasks"
: "%s's persoonlijke taken"

, "GENDER_Task"
: ""

, "Due"
: "vervallen"

, "Class"
: ""

, "Description"
: "Omschrijving"

, "Geo"
: ""

, "Location"
: ""

, "Lead"
: "Hoofdtaak"

, "Telephone"
: "Telefoon"

, "Email"
: "Email"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: "Alle taken van mijn takenlijst"

, "My open tasks"
: "Mijn open taken"

, "My open tasks this week"
: "Mijn open taken deze week"

, "All tasks for me"
: "Alle taken voor mij"

, "All tasks that I am responsible for"
: "Alle taken waar ik verantwoordelijk voor ben"

, "Last modified by me"
: "Laatst aangepast door mij"

, "All tasks that I have last modified"
: "Alle taken die die ik als laatst heb aangepast"

, "Tasks without responsible"
: "Taken zonder verantwoordelijke"

, "manage shared task lists"
: "Beheer gedeelde taken lijst"

, "Create new shared tasks lists"
: "Maak nieuwe gedeelde taken lijst"

, "manage shared tasks favorites"
: "Beheer gedeelde taak favorieten"

, "Create or update shared tasks favorites"
: "Maak of update gedeelde taak favorieten"

, "Status"
: "Status"

, "Do you really want to delete the selected task?"
: "Wil je deze taak echt verwijderen?"

, "Task"
: "Taak"

, "to do list"
: "to do lijst"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
